'''Apport package hook for Network Manager

(c) 2008 Canonical Ltd.
Contributors:
Matt Zimmerman <mdz@canonical.com>
Martin Pitt <martin.pitt@canonical.com>

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.  See http://www.gnu.org/copyleft/gpl.html for
the full text of the license.
'''

import os
import subprocess
from apport.hookutils import *

# TODO:
# - Replace lshal usage with the appropriate new-world-order stuff (udevinfo?)

def _network_interfaces():
    output = command_output(['hal-find-by-capability','--capability','net'])
    udis = output.split('\n')
    interfaces = {}
    for udi in udis:
        interface = command_output(['hal-get-property','--udi',udi,'--key','net.interface'])
        device = command_output(['hal-get-property','--udi',udi,'--key','net.originating_device'])

        interfaces[interface] = device

    return interfaces
                
def _device_details(device):
    return command_output(['lshal','-u',device])

def add_info(report):
    attach_network(report)
    attach_wifi(report)

    attach_file_if_exists(report, '/etc/NetworkManager/nm-system-settings.conf', 'nm-system-settings.conf')

    report['Gconf'] = command_output(['gconftool-2','-R','/system/networking'])
    report['Keyfiles'] = command_output(['ls -l','/etc/NetworkManager/system-connections/'])

    for interface, device in _network_interfaces().items():
        key = 'NetDevice.%s' % interface
        report[key] = _device_details(device)

    interesting_modules = { 'ndiswrapper' : 'driver-ndiswrapper',
                            'ath_hal' : 'driver-madwifi',
                            'b44' : 'driver-b44' }
    interesting_modules_loaded = []
    tags = []
    for line in open('/proc/modules'):
        module = line.split()[0]
        if module in interesting_modules:
            tags.append(interesting_modules[module])
            interesting_modules_loaded.append(module)

    if interesting_modules_loaded:
        report['InterestingModules'] = ' '.join(interesting_modules_loaded)
    	report.setdefault('Tags', '')
    	report['Tags'] += ' ' + ' '.join(tags)

if __name__ == '__main__':
    report = {}
    report['CrashDB'] = 'ubuntu'
    add_info(report)
    for key in report:
        print '%s: %s' % (key, report[key].split('\n', 1)[0])
